@@ -1,3 +1,5 @@
+from pyzeebe.client.client import ZeebeClient
+from pyzeebe.common import exceptions
 from pyzeebe.task.task import Task
 from pyzeebe.task.task_context import TaskContext
 from pyzeebe.task.task_status_controller import TaskStatusController
