@@ -1,10 +1,13 @@
 from typing import Dict
 
+from pyzeebe.task.task_status import TaskStatus
 
-class TaskContext:
+
+class TaskContext(object):
     def __init__(self, key: int, _type: str, workflow_instance_key: int, bpmn_process_id: str,
                  workflow_definition_version: int, workflow_key: int, element_id: str, element_instance_key: int,
-                 custom_headers: Dict, worker: str, retries: int, deadline: int, variables: Dict):
+                 custom_headers: Dict, worker: str, retries: int, deadline: int, variables: Dict,
+                 status: TaskStatus = TaskStatus.Running):
         self.key = key
         self.type = _type
         self.workflow_instance_key = workflow_instance_key
@@ -18,6 +21,7 @@ class TaskContext:
         self.retries = retries
         self.deadline = deadline
         self.variables = variables
+        self.status = status
 
     def __repr__(self):
         return str({'jobKey': self.key, 'taskType': self.type, 'workflowInstanceKey': self.workflow_instance_key,
