@@ -2,7 +2,7 @@ from pyzeebe.grpc_internals.zeebe_adapter import ZeebeAdapter
 from pyzeebe.task.task_context import TaskContext
 
 
-class TaskStatusController:
+class TaskStatusController(object):
     def __init__(self, context: TaskContext, zeebe_adapter: ZeebeAdapter):
         self.zeebe_adapter = zeebe_adapter
         self.context = context
